==> integration-tests-jobs-service-springboot-1.19.0.Final-sources.jar: org/acme/travels/AsyncProcess.java <==
package org.acme.travels;

import org.kie.api.definition.process.Process;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.drools.core.util.KieFunctions;
import org.jbpm.process.core.datatype.impl.type.StringDataType;

@org.springframework.stereotype.Component("async")
public class AsyncProcess extends org.kie.kogito.process.impl.AbstractProcess<org.acme.travels.AsyncModel> {

    public AsyncProcess(org.kie.kogito.app.Application app) {
        this(app, new org.kie.kogito.handlers.HelloService_bye_8_Handler(), new org.kie.kogito.handlers.HelloService_hello_9_Handler());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    public AsyncProcess(org.kie.kogito.app.Application app, org.kie.kogito.handlers.HelloService_bye_8_Handler helloService_bye_8_Handler, org.kie.kogito.handlers.HelloService_hello_9_Handler helloService_hello_9_Handler) {
        super(app, java.util.Arrays.asList(helloService_bye_8_Handler, helloService_hello_9_Handler));
        activate();
    }

    public AsyncProcess() {
    }

    @Override()
    public org.acme.travels.AsyncProcessInstance createInstance(org.acme.travels.AsyncModel value) {
        return new org.acme.travels.AsyncProcessInstance(this, value, this.createProcessRuntime());
    }

    public org.acme.travels.AsyncProcessInstance createInstance(java.lang.String businessKey, org.acme.travels.AsyncModel value) {
        return new org.acme.travels.AsyncProcessInstance(this, value, businessKey, this.createProcessRuntime());
    }

    @Override()
    public org.acme.travels.AsyncModel createModel() {
        return new org.acme.travels.AsyncModel();
    }

    public org.acme.travels.AsyncProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.acme.travels.AsyncModel) value);
    }

    public org.acme.travels.AsyncProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.Model value) {
        return this.createInstance(businessKey, (org.acme.travels.AsyncModel) value);
    }

    public org.acme.travels.AsyncProcessInstance createInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.travels.AsyncProcessInstance(this, this.createModel(), this.createProcessRuntime(), wpi);
    }

    public org.acme.travels.AsyncProcessInstance createReadOnlyInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.travels.AsyncProcessInstance(this, this.createModel(), wpi);
    }

    protected org.kie.api.definition.process.Process process() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("async");
        factory.variable("name", org.jbpm.process.core.datatype.DataTypeResolver.fromClass(java.lang.String.class), null, "customTags", null);
        factory.variable("hello", org.jbpm.process.core.datatype.DataTypeResolver.fromClass(java.lang.String.class), null, "customTags", null);
        factory.variable("bye", org.jbpm.process.core.datatype.DataTypeResolver.fromClass(java.lang.String.class), null, "customTags", null);
        factory.name("async");
        factory.packageName("org.acme.travels");
        factory.dynamic(false);
        factory.version("1.0");
        factory.visibility("Public");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode1 = factory.actionNode(1);
        actionNode1.name("ScriptBeforeBye");
        actionNode1.action(kcontext -> {
            java.lang.String bye = (java.lang.String) kcontext.getVariable("bye");
            System.out.println(java.time.LocalDateTime.now() + " ScriptBeforeBye: Asynchronous bye task will be started for the processInstance: " + kcontext.getProcessInstance().getStringId());
        });
        actionNode1.metaData("UniqueId", "_D7726482-A468-4CBC-92C3-DFD5F69AB971");
        actionNode1.metaData("elementname", "ScriptBeforeBye");
        actionNode1.metaData("NodeType", "ScriptTask");
        actionNode1.metaData("x", 1062);
        actionNode1.metaData("width", 201);
        actionNode1.metaData("y", 206);
        actionNode1.metaData("height", 94);
        actionNode1.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode2 = factory.actionNode(2);
        actionNode2.name("ScriptFeforeHello");
        actionNode2.action(kcontext -> {
            java.lang.String hello = (java.lang.String) kcontext.getVariable("hello");
            System.out.println(java.time.LocalDateTime.now() + " ScriptBeforeHello: Asynchronous hello task will be started for the processInstance: " + kcontext.getProcessInstance().getStringId());
        });
        actionNode2.metaData("UniqueId", "_B1BFE192-7CB3-4A2E-A493-B5A56F9E2018");
        actionNode2.metaData("elementname", "ScriptFeforeHello");
        actionNode2.metaData("NodeType", "ScriptTask");
        actionNode2.metaData("x", 192);
        actionNode2.metaData("width", 194);
        actionNode2.metaData("y", 203);
        actionNode2.metaData("height", 99);
        actionNode2.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode3 = factory.actionNode(3);
        actionNode3.name("ScriptAfterBye");
        actionNode3.action(kcontext -> {
            java.lang.String bye = (java.lang.String) kcontext.getVariable("bye");
            System.out.println(java.time.LocalDateTime.now() + " ScriptAfterBye: Asynchronous bye task was executed for the processInstance: " + kcontext.getProcessInstance().getStringId());
        });
        actionNode3.metaData("UniqueId", "_013791BF-7A12-409D-B82C-8797E8C8ED67");
        actionNode3.metaData("elementname", "ScriptAfterBye");
        actionNode3.metaData("NodeType", "ScriptTask");
        actionNode3.metaData("x", 1612);
        actionNode3.metaData("width", 178);
        actionNode3.metaData("y", 204);
        actionNode3.metaData("height", 98);
        actionNode3.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode4 = factory.actionNode(4);
        actionNode4.name("ScrptAfterHello");
        actionNode4.action(kcontext -> {
            java.lang.String hello = (java.lang.String) kcontext.getVariable("hello");
            System.out.println(java.time.LocalDateTime.now() + " ScriptAfterHello: Asynchronous hello task was executed for the processInstance: " + kcontext.getProcessInstance().getStringId());
        });
        actionNode4.metaData("UniqueId", "_44138B50-463B-43A0-BA35-513C1650ACB9");
        actionNode4.metaData("elementname", "ScrptAfterHello");
        actionNode4.metaData("NodeType", "ScriptTask");
        actionNode4.metaData("x", 692);
        actionNode4.metaData("width", 164);
        actionNode4.metaData("y", 201);
        actionNode4.metaData("height", 103);
        actionNode4.done();
        org.jbpm.ruleflow.core.factory.EventNodeFactory<?> eventNode5 = factory.eventNode(5);
        eventNode5.name("complete");
        eventNode5.eventType("complete");
        eventNode5.metaData("UniqueId", "_3A4800AB-2B7A-490E-9D57-44F289795143");
        eventNode5.metaData("elementname", "complete");
        eventNode5.metaData("EventType", "signal");
        eventNode5.metaData("x", 1851);
        eventNode5.metaData("width", 56);
        eventNode5.metaData("y", 225);
        eventNode5.metaData("height", 56);
        eventNode5.done();
        org.jbpm.ruleflow.core.factory.EndNodeFactory<?> endNode6 = factory.endNode(6);
        endNode6.name("End");
        endNode6.terminate(false);
        endNode6.metaData("UniqueId", "_B9E500DD-6557-4587-B167-B93C0A9366F4");
        endNode6.metaData("x", 1956);
        endNode6.metaData("width", 56);
        endNode6.metaData("y", 224);
        endNode6.metaData("height", 56);
        endNode6.done();
        org.jbpm.ruleflow.core.factory.EventNodeFactory<?> eventNode7 = factory.eventNode(7);
        eventNode7.name("bye");
        eventNode7.eventType("bye");
        eventNode7.metaData("UniqueId", "_7E4B483A-094F-40F5-BCA2-6FB6317A2379");
        eventNode7.metaData("elementname", "bye");
        eventNode7.metaData("EventType", "signal");
        eventNode7.metaData("x", 923);
        eventNode7.metaData("width", 56);
        eventNode7.metaData("y", 225);
        eventNode7.metaData("height", 56);
        eventNode7.done();
        org.jbpm.ruleflow.core.factory.WorkItemNodeFactory<?> workItemNode8 = factory.workItemNode(8);
        workItemNode8.name("bye");
        workItemNode8.workName("org.kie.kogito.HelloService_bye_8_Handler");
        workItemNode8.workParameter("NodeName", "bye");
        workItemNode8.workParameter("Interface", "org.kie.kogito.HelloService");
        workItemNode8.workParameter("Operation", "bye");
        workItemNode8.workParameter("interfaceImplementationRef", "org.kie.kogito.HelloService");
        workItemNode8.workParameter("operationImplementationRef", "bye");
        workItemNode8.workParameter("implementation", "Java");
        workItemNode8.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(new org.jbpm.workflow.core.impl.DataDefinition("name", "name", "java.lang.Object", null)), new org.jbpm.workflow.core.impl.DataDefinition("_D8FA244A-DFC4-49BE-AA83-49B6CD8F043E_nameInputX", "name", "String", null), null, null));
        workItemNode8.mapDataOutputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(new org.jbpm.workflow.core.impl.DataDefinition("_D8FA244A-DFC4-49BE-AA83-49B6CD8F043E_responseOutputX", "response", "String", null)), new org.jbpm.workflow.core.impl.DataDefinition("bye", "bye", "java.lang.Object", null), null, null));
        workItemNode8.done();
        workItemNode8.metaData("UniqueId", "_D8FA244A-DFC4-49BE-AA83-49B6CD8F043E");
        workItemNode8.metaData("customAsync", "true");
        workItemNode8.metaData("Implementation", "Java");
        workItemNode8.metaData("elementname", "bye");
        workItemNode8.metaData("Type", "Service Task");
        workItemNode8.metaData("OperationRef", "_D8FA244A-DFC4-49BE-AA83-49B6CD8F043E_ServiceOperation");
        workItemNode8.metaData("x", 1381);
        workItemNode8.metaData("width", 154);
        workItemNode8.metaData("y", 202);
        workItemNode8.metaData("height", 102);
        org.jbpm.ruleflow.core.factory.WorkItemNodeFactory<?> workItemNode9 = factory.workItemNode(9);
        workItemNode9.name("hello");
        workItemNode9.workName("org.kie.kogito.HelloService_hello_9_Handler");
        workItemNode9.workParameter("NodeName", "hello");
        workItemNode9.workParameter("Interface", "org.kie.kogito.HelloService");
        workItemNode9.workParameter("Operation", "hello");
        workItemNode9.workParameter("interfaceImplementationRef", "org.kie.kogito.HelloService");
        workItemNode9.workParameter("operationImplementationRef", "hello");
        workItemNode9.workParameter("implementation", "Java");
        workItemNode9.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(new org.jbpm.workflow.core.impl.DataDefinition("name", "name", "java.lang.Object", null)), new org.jbpm.workflow.core.impl.DataDefinition("_EE3B03C0-61FF-4123-951D-B23EDCD7DC7F_nameInputX", "name", "String", null), null, null));
        workItemNode9.mapDataOutputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(new org.jbpm.workflow.core.impl.DataDefinition("_EE3B03C0-61FF-4123-951D-B23EDCD7DC7F_responseOutputX", "response", "String", null)), new org.jbpm.workflow.core.impl.DataDefinition("hello", "hello", "java.lang.Object", null), null, null));
        workItemNode9.done();
        workItemNode9.metaData("UniqueId", "_EE3B03C0-61FF-4123-951D-B23EDCD7DC7F");
        workItemNode9.metaData("customAsync", "true");
        workItemNode9.metaData("Implementation", "Java");
        workItemNode9.metaData("elementname", "hello");
        workItemNode9.metaData("Type", "Service Task");
        workItemNode9.metaData("OperationRef", "_EE3B03C0-61FF-4123-951D-B23EDCD7DC7F_ServiceOperation");
        workItemNode9.metaData("x", 471);
        workItemNode9.metaData("width", 154);
        workItemNode9.metaData("y", 201);
        workItemNode9.metaData("height", 102);
        org.jbpm.ruleflow.core.factory.StartNodeFactory<?> startNode10 = factory.startNode(10);
        startNode10.name("Start");
        startNode10.interrupting(false);
        startNode10.metaData("UniqueId", "_459575F0-71A6-4ECB-A809-AB04213A3EF9");
        startNode10.metaData("x", 80);
        startNode10.metaData("width", 56);
        startNode10.metaData("y", 225);
        startNode10.metaData("height", 56);
        startNode10.done();
        factory.connection(7, 1, "_401EE160-A749-45DB-9A70-20E46E0BBAF3");
        factory.connection(10, 2, "_0D4D4D93-5443-408F-87E7-B9F6D85397DC");
        factory.connection(8, 3, "_8E6BB681-019C-4A65-A032-D491576578ED");
        factory.connection(9, 4, "_081637BA-F35A-478C-AD70-72A1BDA1F4D6");
        factory.connection(3, 5, "_3A8EA38E-1056-4627-A3DA-15B587FA797E");
        factory.connection(5, 6, "_B16F4B51-57C0-4959-A5EF-461A4A4E8FDE");
        factory.connection(4, 7, "_E4A84B45-826F-45BF-8C3A-1DEF9BE10497");
        factory.connection(1, 8, "_8F774350-A5F0-4711-A167-E41A51EB9B73");
        factory.connection(2, 9, "_8F76A112-D2E8-4F9C-912B-1E9586FB753C");
        factory.validate();
        return factory.getProcess();
    }
}

==> integration-tests-jobs-service-springboot-1.31.1.Final-sources.jar: org/acme/travels/AsyncProcess.java <==
package org.acme.travels;

import org.acme.travels.AsyncModel;
import org.kie.api.definition.process.Process;
import org.jbpm.ruleflow.core.RuleFlowProcessFactory;
import org.jbpm.process.core.datatype.impl.type.ObjectDataType;
import org.drools.core.util.KieFunctions;
import org.jbpm.process.core.datatype.impl.type.StringDataType;

@org.springframework.stereotype.Component("async")
public class AsyncProcess extends org.kie.kogito.process.impl.AbstractProcess<org.acme.travels.AsyncModel> {

    public AsyncProcess(org.kie.kogito.app.Application app, org.kie.kogito.correlation.CorrelationService correlations) {
        this(app, correlations, new org.kie.kogito.handlers.HelloService_bye_8_Handler(), new org.kie.kogito.handlers.HelloService_hello_9_Handler());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    public AsyncProcess(org.kie.kogito.app.Application app, org.kie.kogito.correlation.CorrelationService correlations, org.kie.kogito.handlers.HelloService_bye_8_Handler helloService_bye_8_Handler, org.kie.kogito.handlers.HelloService_hello_9_Handler helloService_hello_9_Handler) {
        super(app, java.util.Arrays.asList(helloService_bye_8_Handler, helloService_hello_9_Handler), correlations);
        activate();
    }

    public AsyncProcess() {
    }

    @Override()
    public org.acme.travels.AsyncProcessInstance createInstance(org.acme.travels.AsyncModel value) {
        return new org.acme.travels.AsyncProcessInstance(this, value, this.createProcessRuntime());
    }

    public org.acme.travels.AsyncProcessInstance createInstance(java.lang.String businessKey, org.acme.travels.AsyncModel value) {
        return new org.acme.travels.AsyncProcessInstance(this, value, businessKey, this.createProcessRuntime());
    }

    public org.acme.travels.AsyncProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.correlation.CompositeCorrelation correlation, org.acme.travels.AsyncModel value) {
        return new org.acme.travels.AsyncProcessInstance(this, value, businessKey, this.createProcessRuntime(), correlation);
    }

    @Override()
    public org.acme.travels.AsyncModel createModel() {
        return new org.acme.travels.AsyncModel();
    }

    public org.acme.travels.AsyncProcessInstance createInstance(org.kie.kogito.Model value) {
        return this.createInstance((org.acme.travels.AsyncModel) value);
    }

    public org.acme.travels.AsyncProcessInstance createInstance(java.lang.String businessKey, org.kie.kogito.Model value) {
        return this.createInstance(businessKey, (org.acme.travels.AsyncModel) value);
    }

    public org.acme.travels.AsyncProcessInstance createInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.travels.AsyncProcessInstance(this, this.createModel(), this.createProcessRuntime(), wpi);
    }

    public org.acme.travels.AsyncProcessInstance createReadOnlyInstance(org.kie.api.runtime.process.WorkflowProcessInstance wpi) {
        return new org.acme.travels.AsyncProcessInstance(this, this.createModel(), wpi);
    }

    protected org.kie.api.definition.process.Process process() {
        RuleFlowProcessFactory factory = RuleFlowProcessFactory.createProcess("async", true);
        factory.variable("name", org.jbpm.process.core.datatype.DataTypeResolver.fromClass(java.lang.String.class), null, "customTags", null);
        factory.variable("hello", org.jbpm.process.core.datatype.DataTypeResolver.fromClass(java.lang.String.class), null, "customTags", null);
        factory.variable("bye", org.jbpm.process.core.datatype.DataTypeResolver.fromClass(java.lang.String.class), null, "customTags", null);
        factory.name("async");
        factory.packageName("org.acme.travels");
        factory.dynamic(false);
        factory.version("1.0");
        factory.type("BPMN");
        factory.visibility("Public");
        factory.metaData("TargetNamespace", "http://www.omg.org/bpmn20");
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode1 = factory.actionNode(1);
        actionNode1.name("ScriptBeforeBye");
        actionNode1.action(kcontext -> {
            java.lang.String bye = (java.lang.String) kcontext.getVariable("bye");
            System.out.println(java.time.LocalDateTime.now() + " ScriptBeforeBye: Asynchronous bye task will be started for the processInstance: " + kcontext.getProcessInstance().getStringId());
        });
        actionNode1.metaData("UniqueId", "_D7726482-A468-4CBC-92C3-DFD5F69AB971");
        actionNode1.metaData("elementname", "ScriptBeforeBye");
        actionNode1.metaData("NodeType", "ScriptTask");
        actionNode1.metaData("x", 1062);
        actionNode1.metaData("width", 201);
        actionNode1.metaData("y", 206);
        actionNode1.metaData("height", 94);
        actionNode1.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode2 = factory.actionNode(2);
        actionNode2.name("ScriptFeforeHello");
        actionNode2.action(kcontext -> {
            java.lang.String hello = (java.lang.String) kcontext.getVariable("hello");
            System.out.println(java.time.LocalDateTime.now() + " ScriptBeforeHello: Asynchronous hello task will be started for the processInstance: " + kcontext.getProcessInstance().getStringId());
        });
        actionNode2.metaData("UniqueId", "_B1BFE192-7CB3-4A2E-A493-B5A56F9E2018");
        actionNode2.metaData("elementname", "ScriptFeforeHello");
        actionNode2.metaData("NodeType", "ScriptTask");
        actionNode2.metaData("x", 192);
        actionNode2.metaData("width", 194);
        actionNode2.metaData("y", 203);
        actionNode2.metaData("height", 99);
        actionNode2.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode3 = factory.actionNode(3);
        actionNode3.name("ScriptAfterBye");
        actionNode3.action(kcontext -> {
            java.lang.String bye = (java.lang.String) kcontext.getVariable("bye");
            System.out.println(java.time.LocalDateTime.now() + " ScriptAfterBye: Asynchronous bye task was executed for the processInstance: " + kcontext.getProcessInstance().getStringId());
        });
        actionNode3.metaData("UniqueId", "_013791BF-7A12-409D-B82C-8797E8C8ED67");
        actionNode3.metaData("elementname", "ScriptAfterBye");
        actionNode3.metaData("NodeType", "ScriptTask");
        actionNode3.metaData("x", 1612);
        actionNode3.metaData("width", 178);
        actionNode3.metaData("y", 204);
        actionNode3.metaData("height", 98);
        actionNode3.done();
        org.jbpm.ruleflow.core.factory.ActionNodeFactory<?> actionNode4 = factory.actionNode(4);
        actionNode4.name("ScrptAfterHello");
        actionNode4.action(kcontext -> {
            java.lang.String hello = (java.lang.String) kcontext.getVariable("hello");
            System.out.println(java.time.LocalDateTime.now() + " ScriptAfterHello: Asynchronous hello task was executed for the processInstance: " + kcontext.getProcessInstance().getStringId());
        });
        actionNode4.metaData("UniqueId", "_44138B50-463B-43A0-BA35-513C1650ACB9");
        actionNode4.metaData("elementname", "ScrptAfterHello");
        actionNode4.metaData("NodeType", "ScriptTask");
        actionNode4.metaData("x", 692);
        actionNode4.metaData("width", 164);
        actionNode4.metaData("y", 201);
        actionNode4.metaData("height", 103);
        actionNode4.done();
        org.jbpm.ruleflow.core.factory.EventNodeFactory<?> eventNode5 = factory.eventNode(5);
        eventNode5.name("complete");
        eventNode5.eventType("complete");
        eventNode5.metaData("UniqueId", "_3A4800AB-2B7A-490E-9D57-44F289795143");
        eventNode5.metaData("elementname", "complete");
        eventNode5.metaData("EventType", "signal");
        eventNode5.metaData("x", 1851);
        eventNode5.metaData("width", 56);
        eventNode5.metaData("y", 225);
        eventNode5.metaData("height", 56);
        eventNode5.done();
        org.jbpm.ruleflow.core.factory.EndNodeFactory<?> endNode6 = factory.endNode(6);
        endNode6.name("End");
        endNode6.terminate(false);
        endNode6.metaData("UniqueId", "_B9E500DD-6557-4587-B167-B93C0A9366F4");
        endNode6.metaData("x", 1956);
        endNode6.metaData("width", 56);
        endNode6.metaData("y", 224);
        endNode6.metaData("height", 56);
        endNode6.done();
        org.jbpm.ruleflow.core.factory.EventNodeFactory<?> eventNode7 = factory.eventNode(7);
        eventNode7.name("bye");
        eventNode7.eventType("bye");
        eventNode7.metaData("UniqueId", "_7E4B483A-094F-40F5-BCA2-6FB6317A2379");
        eventNode7.metaData("elementname", "bye");
        eventNode7.metaData("EventType", "signal");
        eventNode7.metaData("x", 923);
        eventNode7.metaData("width", 56);
        eventNode7.metaData("y", 225);
        eventNode7.metaData("height", 56);
        eventNode7.done();
        org.jbpm.ruleflow.core.factory.WorkItemNodeFactory<?> workItemNode8 = factory.workItemNode(8);
        workItemNode8.name("bye");
        workItemNode8.workName("org.kie.kogito.HelloService_bye_8_Handler");
        workItemNode8.workParameter("NodeName", "bye");
        workItemNode8.workParameter("Interface", "org.kie.kogito.HelloService");
        workItemNode8.workParameter("Operation", "bye");
        workItemNode8.workParameter("interfaceImplementationRef", "org.kie.kogito.HelloService");
        workItemNode8.workParameter("operationImplementationRef", "bye");
        workItemNode8.workParameter("implementation", "Java");
        workItemNode8.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(new org.jbpm.workflow.core.impl.DataDefinition("name", "name", "java.lang.Object", null)), new org.jbpm.workflow.core.impl.DataDefinition("_D8FA244A-DFC4-49BE-AA83-49B6CD8F043E_nameInputX", "name", "String", null), null, null));
        workItemNode8.mapDataOutputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(new org.jbpm.workflow.core.impl.DataDefinition("_D8FA244A-DFC4-49BE-AA83-49B6CD8F043E_responseOutputX", "response", "String", null)), new org.jbpm.workflow.core.impl.DataDefinition("bye", "bye", "java.lang.Object", null), null, null));
        workItemNode8.done();
        workItemNode8.metaData("UniqueId", "_D8FA244A-DFC4-49BE-AA83-49B6CD8F043E");
        workItemNode8.metaData("customAsync", "true");
        workItemNode8.metaData("Implementation", "Java");
        workItemNode8.metaData("elementname", "bye");
        workItemNode8.metaData("Type", "Service Task");
        workItemNode8.metaData("OperationRef", "_D8FA244A-DFC4-49BE-AA83-49B6CD8F043E_ServiceOperation");
        workItemNode8.metaData("x", 1381);
        workItemNode8.metaData("width", 154);
        workItemNode8.metaData("y", 202);
        workItemNode8.metaData("height", 102);
        org.jbpm.ruleflow.core.factory.WorkItemNodeFactory<?> workItemNode9 = factory.workItemNode(9);
        workItemNode9.name("hello");
        workItemNode9.workName("org.kie.kogito.HelloService_hello_9_Handler");
        workItemNode9.workParameter("NodeName", "hello");
        workItemNode9.workParameter("Interface", "org.kie.kogito.HelloService");
        workItemNode9.workParameter("Operation", "hello");
        workItemNode9.workParameter("interfaceImplementationRef", "org.kie.kogito.HelloService");
        workItemNode9.workParameter("operationImplementationRef", "hello");
        workItemNode9.workParameter("implementation", "Java");
        workItemNode9.mapDataInputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(new org.jbpm.workflow.core.impl.DataDefinition("name", "name", "java.lang.Object", null)), new org.jbpm.workflow.core.impl.DataDefinition("_EE3B03C0-61FF-4123-951D-B23EDCD7DC7F_nameInputX", "name", "String", null), null, null));
        workItemNode9.mapDataOutputAssociation(new org.jbpm.workflow.core.impl.DataAssociation(java.util.Arrays.asList(new org.jbpm.workflow.core.impl.DataDefinition("_EE3B03C0-61FF-4123-951D-B23EDCD7DC7F_responseOutputX", "response", "String", null)), new org.jbpm.workflow.core.impl.DataDefinition("hello", "hello", "java.lang.Object", null), null, null));
        workItemNode9.done();
        workItemNode9.metaData("UniqueId", "_EE3B03C0-61FF-4123-951D-B23EDCD7DC7F");
        workItemNode9.metaData("customAsync", "true");
        workItemNode9.metaData("Implementation", "Java");
        workItemNode9.metaData("elementname", "hello");
        workItemNode9.metaData("Type", "Service Task");
        workItemNode9.metaData("OperationRef", "_EE3B03C0-61FF-4123-951D-B23EDCD7DC7F_ServiceOperation");
        workItemNode9.metaData("x", 471);
        workItemNode9.metaData("width", 154);
        workItemNode9.metaData("y", 201);
        workItemNode9.metaData("height", 102);
        org.jbpm.ruleflow.core.factory.StartNodeFactory<?> startNode10 = factory.startNode(10);
        startNode10.name("Start");
        startNode10.interrupting(false);
        startNode10.metaData("UniqueId", "_459575F0-71A6-4ECB-A809-AB04213A3EF9");
        startNode10.metaData("x", 80);
        startNode10.metaData("width", 56);
        startNode10.metaData("y", 225);
        startNode10.metaData("height", 56);
        startNode10.done();
        factory.connection(7, 1, "_401EE160-A749-45DB-9A70-20E46E0BBAF3");
        factory.connection(10, 2, "_0D4D4D93-5443-408F-87E7-B9F6D85397DC");
        factory.connection(8, 3, "_8E6BB681-019C-4A65-A032-D491576578ED");
        factory.connection(9, 4, "_081637BA-F35A-478C-AD70-72A1BDA1F4D6");
        factory.connection(3, 5, "_3A8EA38E-1056-4627-A3DA-15B587FA797E");
        factory.connection(5, 6, "_B16F4B51-57C0-4959-A5EF-461A4A4E8FDE");
        factory.connection(4, 7, "_E4A84B45-826F-45BF-8C3A-1DEF9BE10497");
        factory.connection(1, 8, "_8F774350-A5F0-4711-A167-E41A51EB9B73");
        factory.connection(2, 9, "_8F76A112-D2E8-4F9C-912B-1E9586FB753C");
        factory.validate();
        return factory.getProcess();
    }
}
